@@ -76,7 +76,7 @@ typedef struct
 	/* command line parsing */
 	gboolean new_window;
 	gboolean new_document;
-	const GtkSourceEncoding *encoding;
+	GtkSourceEncoding *encoding;
 	GInputStream *stdin_stream;
 	GSList *file_list;
 	gint line_position;
@@ -166,6 +166,8 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&priv->notebook_menu);
 	g_clear_object (&priv->tab_width_menu);
 
+	g_clear_pointer (&priv->encoding, (GDestroyNotify) gtk_source_encoding_free);
+
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
 
@@ -820,10 +822,10 @@ clear_options (GeditApp *app)
 
 	g_clear_object (&priv->stdin_stream);
 	g_slist_free_full (priv->file_list, g_object_unref);
+	g_clear_pointer (&priv->encoding, (GDestroyNotify) gtk_source_encoding_free);
 
 	priv->new_window = FALSE;
 	priv->new_document = FALSE;
-	priv->encoding = NULL;
 	priv->file_list = NULL;
 	priv->line_position = 0;
 	priv->column_position = 0;
@@ -878,13 +880,17 @@ gedit_app_command_line (GApplication            *application,
 
 	if (g_variant_dict_lookup (options, "encoding", "&s", &encoding_charset))
 	{
-		priv->encoding = gtk_source_encoding_get_from_charset (encoding_charset);
+		gtk_source_encoding_free (priv->encoding);
+		priv->encoding = gtk_source_encoding_new (encoding_charset);
 
-		if (priv->encoding == NULL)
+		if (!gtk_source_encoding_has_known_charset (priv->encoding))
 		{
 			g_application_command_line_printerr (cl,
 							     _("%s: invalid encoding."),
 							     encoding_charset);
+
+			gtk_source_encoding_free (priv->encoding);
+			priv->encoding = NULL;
 		}
 	}
 
@@ -947,7 +953,7 @@ print_all_encodings (void)
 		g_print ("%s\n", gtk_source_encoding_get_charset (encoding));
 	}
 
-	g_slist_free (all_encodings);
+	g_slist_free_full (all_encodings, (GDestroyNotify) gtk_source_encoding_free);
 }
 
 static gint
