@@ -480,26 +480,28 @@ set_language (GeditDocument     *doc,
 static void
 save_encoding_metadata (GeditDocument *doc)
 {
-	GeditDocumentPrivate *priv;
+	GeditDocumentPrivate *priv = gedit_document_get_instance_private (doc);
 	const GtkSourceEncoding *encoding;
+	GtkSourceEncoding *utf8_encoding;
 	const gchar *charset;
 
-	gedit_debug (DEBUG_DOCUMENT);
-
-	priv = gedit_document_get_instance_private (doc);
-
 	encoding = gtk_source_file_get_encoding (priv->file);
+	utf8_encoding = gtk_source_encoding_new_utf8 ();
 
-	if (encoding == NULL)
+	if (encoding != NULL)
 	{
-		encoding = gtk_source_encoding_get_utf8 ();
+		charset = gtk_source_encoding_get_charset (encoding);
+	}
+	else
+	{
+		charset = gtk_source_encoding_get_charset (utf8_encoding);
 	}
-
-	charset = gtk_source_encoding_get_charset (encoding);
 
 	gedit_document_set_metadata (doc,
 				     GEDIT_METADATA_ATTRIBUTE_ENCODING, charset,
 				     NULL);
+
+	gtk_source_encoding_free (utf8_encoding);
 }
 
 static GtkSourceLanguage *
